==> jc-1.4.0.tar.gz: gnu/java/awt/image/XBMDecoder.h <==
// public class gnu.java.awt.image.XBMDecoder

// class file dependencies
// @dep_class ddccf95482e2e69 gnu_java_awt_image_ImageDecoder
// @dep_class 62b3f9190edb1333 gnu_java_awt_image_XBMDecoder
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_image_ImageDecoder

#include "gnu/java/awt/image/ImageDecoder.h"

#ifndef _JC_gnu_java_awt_image_XBMDecoder_H_
#define _JC_gnu_java_awt_image_XBMDecoder_H_

// Forward structure declarations
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_io_BufferedReader$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_io_Reader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_gnu_java_awt_image_XBMDecoder$sub_refs	_jc_gnu_java_awt_image_XBMDecoder$sub_refs;
typedef struct _jc_gnu_java_awt_image_XBMDecoder$sub_nonrefs	_jc_gnu_java_awt_image_XBMDecoder$sub_nonrefs;
typedef struct _jc_gnu_java_awt_image_XBMDecoder$refs	_jc_gnu_java_awt_image_XBMDecoder$refs;
typedef struct _jc_gnu_java_awt_image_XBMDecoder$nonrefs	_jc_gnu_java_awt_image_XBMDecoder$nonrefs;
typedef struct _jc_gnu_java_awt_image_XBMDecoder$object	_jc_gnu_java_awt_image_XBMDecoder$object;

typedef struct _jc_gnu_java_awt_image_XBMDecoder$fields_struct	_jc_gnu_java_awt_image_XBMDecoder$fields_struct;
typedef const struct _jc_gnu_java_awt_image_XBMDecoder$vmethods	_jc_gnu_java_awt_image_XBMDecoder$vmethods;
typedef const struct _jc_gnu_java_awt_image_XBMDecoder$vtable	_jc_gnu_java_awt_image_XBMDecoder$vtable;
typedef const struct _jc_gnu_java_awt_image_XBMDecoder$vtype	_jc_gnu_java_awt_image_XBMDecoder$vtype;

// Class fields structure
struct _jc_gnu_java_awt_image_XBMDecoder$fields_struct {
	struct _jc_java_awt_image_ColorModel$object	*cm;
	_jc_int_array	*masktable;
	jint	black;
	jint	transparent;
};
extern _jc_gnu_java_awt_image_XBMDecoder$fields_struct _jc_gnu_java_awt_image_XBMDecoder$class_fields;

// Constructors
extern void _jc_gnu_java_awt_image_XBMDecoder$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_awt_image_XBMDecoder$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_awt_image_XBMDecoder$method$_init$52b89ab562ab928f(_jc_env *, struct _jc_gnu_java_awt_image_XBMDecoder$object *, struct _jc_java_net_URL$object *);

// Virtual methods
extern void _jc_gnu_java_awt_image_XBMDecoder$method$produce$835eb8bb105fd533(_jc_env *, struct _jc_gnu_java_awt_image_XBMDecoder$object *, struct _jc_java_util_Vector$object *, struct _jc_java_io_InputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_image_XBMDecoder$method_info$produce$835eb8bb105fd533;

// Static methods
extern void _jc_gnu_java_awt_image_XBMDecoder$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern _jc_int_array *_jc_gnu_java_awt_image_XBMDecoder$method$getScanline$eb5d54d4d58d1cae(_jc_env *, struct _jc_java_io_Reader$object *, jint);

// Virtual methods structure
struct _jc_gnu_java_awt_image_XBMDecoder$vmethods {
	void	(*produce$835eb8bb105fd533)(_jc_env *, struct _jc_gnu_java_awt_image_XBMDecoder$object *, struct _jc_java_util_Vector$object *, struct _jc_java_io_InputStream$object *);
};

// Vtable
struct _jc_gnu_java_awt_image_XBMDecoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_image_ImageDecoder$vmethods	gnu_java_awt_image_ImageDecoder;
	_jc_gnu_java_awt_image_XBMDecoder$vmethods	gnu_java_awt_image_XBMDecoder;
};

// Vtype
struct _jc_gnu_java_awt_image_XBMDecoder$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_image_XBMDecoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_image_XBMDecoder$sub_refs {
	struct _jc_java_io_BufferedReader$object	*reader;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_image_XBMDecoder$refs {
    _jc_gnu_java_awt_image_XBMDecoder$sub_refs	gnu_java_awt_image_XBMDecoder;
    _jc_gnu_java_awt_image_ImageDecoder$sub_refs	gnu_java_awt_image_ImageDecoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_image_XBMDecoder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_image_XBMDecoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_image_ImageDecoder$sub_nonrefs	gnu_java_awt_image_ImageDecoder;
    _jc_gnu_java_awt_image_XBMDecoder$sub_nonrefs	gnu_java_awt_image_XBMDecoder;
};

// Object instance structure
struct _jc_gnu_java_awt_image_XBMDecoder$object {
	_jc_gnu_java_awt_image_XBMDecoder$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_image_XBMDecoder$vtype	*vtype;
	_jc_gnu_java_awt_image_XBMDecoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_image_XBMDecoder$vtype _jc_gnu_java_awt_image_XBMDecoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_image_XBMDecoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_image_XBMDecoder$class_object;

#endif	/* _JC_gnu_java_awt_image_XBMDecoder_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/image/XBMDecoder.h <==
// public class gnu.java.awt.image.XBMDecoder

// class file dependencies
// @dep_class ddccf95482e2e69 gnu_java_awt_image_ImageDecoder
// @dep_class 62b3f9190edb1333 gnu_java_awt_image_XBMDecoder
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_image_ImageDecoder

#include "gnu/java/awt/image/ImageDecoder.h"

#ifndef _JC_gnu_java_awt_image_XBMDecoder_H_
#define _JC_gnu_java_awt_image_XBMDecoder_H_

// Forward structure declarations
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_io_BufferedReader$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_io_Reader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_gnu_java_awt_image_XBMDecoder$sub_refs	_jc_gnu_java_awt_image_XBMDecoder$sub_refs;
typedef struct _jc_gnu_java_awt_image_XBMDecoder$sub_nonrefs	_jc_gnu_java_awt_image_XBMDecoder$sub_nonrefs;
typedef struct _jc_gnu_java_awt_image_XBMDecoder$refs	_jc_gnu_java_awt_image_XBMDecoder$refs;
typedef struct _jc_gnu_java_awt_image_XBMDecoder$nonrefs	_jc_gnu_java_awt_image_XBMDecoder$nonrefs;
typedef struct _jc_gnu_java_awt_image_XBMDecoder$object	_jc_gnu_java_awt_image_XBMDecoder$object;

typedef struct _jc_gnu_java_awt_image_XBMDecoder$fields_struct	_jc_gnu_java_awt_image_XBMDecoder$fields_struct;
typedef const struct _jc_gnu_java_awt_image_XBMDecoder$vmethods	_jc_gnu_java_awt_image_XBMDecoder$vmethods;
typedef const struct _jc_gnu_java_awt_image_XBMDecoder$vtable	_jc_gnu_java_awt_image_XBMDecoder$vtable;
typedef const struct _jc_gnu_java_awt_image_XBMDecoder$vtype	_jc_gnu_java_awt_image_XBMDecoder$vtype;

// Class fields structure
struct _jc_gnu_java_awt_image_XBMDecoder$fields_struct {
	struct _jc_java_awt_image_ColorModel$object	*cm;
	_jc_int_array	*masktable;
	jint	black;
	jint	transparent;
};
extern _jc_gnu_java_awt_image_XBMDecoder$fields_struct _jc_gnu_java_awt_image_XBMDecoder$class_fields;

// Constructors
extern void _jc_gnu_java_awt_image_XBMDecoder$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_awt_image_XBMDecoder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_image_XBMDecoder$method$_init$52b89ab562ab928f(_jc_env *, struct _jc_gnu_java_awt_image_XBMDecoder$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_image_XBMDecoder$method$produce$835eb8bb105fd533(_jc_env *, struct _jc_gnu_java_awt_image_XBMDecoder$object *, struct _jc_java_util_Vector$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_image_XBMDecoder$method_info$produce$835eb8bb105fd533;

// Static methods
extern void _jc_gnu_java_awt_image_XBMDecoder$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern _jc_int_array *_jc_gnu_java_awt_image_XBMDecoder$method$getScanline$eb5d54d4d58d1cae(_jc_env *, struct _jc_java_io_Reader$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_image_XBMDecoder$vmethods {
	void	(*produce$835eb8bb105fd533)(_jc_env *, struct _jc_gnu_java_awt_image_XBMDecoder$object *, struct _jc_java_util_Vector$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_image_XBMDecoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_image_ImageDecoder$vmethods	gnu_java_awt_image_ImageDecoder;
	_jc_gnu_java_awt_image_XBMDecoder$vmethods	gnu_java_awt_image_XBMDecoder;
};

// Vtype
struct _jc_gnu_java_awt_image_XBMDecoder$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_image_XBMDecoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_image_XBMDecoder$sub_refs {
	struct _jc_java_io_BufferedReader$object	*reader;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_image_XBMDecoder$refs {
    _jc_gnu_java_awt_image_XBMDecoder$sub_refs	gnu_java_awt_image_XBMDecoder;
    _jc_gnu_java_awt_image_ImageDecoder$sub_refs	gnu_java_awt_image_ImageDecoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_image_XBMDecoder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_image_XBMDecoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_image_ImageDecoder$sub_nonrefs	gnu_java_awt_image_ImageDecoder;
    _jc_gnu_java_awt_image_XBMDecoder$sub_nonrefs	gnu_java_awt_image_XBMDecoder;
};

// Object instance structure
struct _jc_gnu_java_awt_image_XBMDecoder$object {
	_jc_gnu_java_awt_image_XBMDecoder$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_image_XBMDecoder$vtype	*vtype;
	_jc_gnu_java_awt_image_XBMDecoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_image_XBMDecoder$vtype _jc_gnu_java_awt_image_XBMDecoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_image_XBMDecoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_image_XBMDecoder$class_object;

#endif	/* _JC_gnu_java_awt_image_XBMDecoder_H_ */
